@@ -24,11 +24,10 @@ APP_THEME = ["semantic-ui"]
 # See https://invenio-theme.readthedocs.io/en/latest/configuration.html
 
 # Name displayed in tab
-THEME_SITENAME = "TU Data"
+THEME_SITENAME = "TU Wien Research Data"
 
 # Frontpage
 THEME_FRONTPAGE = True
-THEME_FRONTPAGE_TITLE = "TU Data"
 
 # Templates
 BASE_TEMPLATE = "invenio_theme_tuw/page.html"
@@ -49,3 +48,10 @@ ACCOUNTS_COVER_TEMPLATE = "invenio_theme_tuw/login/page_cover.html"
 
 # User profile page
 USERPROFILES_PROFILE_TEMPLATE = "invenio_theme_tuw/settings/profile.html"
+
+
+# Flask-WebpackExt
+# ================
+# See https://flask-webpackext.readthedocs.io/en/latest/configuration.html
+
+WEBPACKEXT_PROJECT = "invenio_theme_tuw.webpack:project"
